# TidyFiles Documentation

## 📚 Public Documentation

- [Contributing Guidelines](../CONTRIBUTING.md)
- [Code of Conduct](../CODE_OF_CONDUCT.md)
- [License](../LICENSE)

## 🔒 Internal Documentation

- [Release Workflow](internal/RELEASE_WORKFLOW.md)
- [Development Guidelines](internal/DEVELOPMENT.md)
- [Architecture Overview](internal/ARCHITECTURE.md)
